[aXSL-commit] SF.net SVN: axsl:[2983] trunk/axsl/axsl-font/src/main /java/org/axsl/font/ConsumerFon
An API for XSL-FO.
Status: Alpha
Brought to you by:
victormote
|
From: <vic...@us...> - 2026-03-07 23:38:59
|
Revision: 2983
http://sourceforge.net/p/axsl/code/2983
Author: victormote
Date: 2026-03-07 23:38:56 +0000 (Sat, 07 Mar 2026)
Log Message:
-----------
Change return type on getFontUses() from List to Collection, to increase flexibility for implementations.
Modified Paths:
--------------
trunk/axsl/axsl-font/src/main/java/org/axsl/font/ConsumerFont.java
Modified: trunk/axsl/axsl-font/src/main/java/org/axsl/font/ConsumerFont.java
===================================================================
--- trunk/axsl/axsl-font/src/main/java/org/axsl/font/ConsumerFont.java 2026-03-07 15:31:57 UTC (rev 2982)
+++ trunk/axsl/axsl-font/src/main/java/org/axsl/font/ConsumerFont.java 2026-03-07 23:38:56 UTC (rev 2983)
@@ -25,7 +25,7 @@
import org.axsl.primitive.sequence.ByteSequence;
-import java.util.List;
+import java.util.Collection;
/**
* <p>A {@link Font} as used by a specific {@link FontConsumer}.
@@ -50,13 +50,12 @@
FontConsumer getFontConsumer();
/**
* Returns the list of child {@link FontUse} instances, i.e. the list of {@link FontUse} instances that have been
* used by {@link #getFontConsumer}.
* This will ordinarily contain only one instance, but in the case of Type1 fonts that require multiple encodings
* for access to all glyphs, it may contain more.
* @return The list of child {@link FontUse} instances.
*/
- List<? extends FontUse> getFontUses();
+ Collection<FontUse> getFontUses();
/**
* Returns the raw font file content, so that it can be embedded in other documents.
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
@@ -50,13 +50,12 @@
FontConsumer getFontConsumer();
/**
- * Returns the list of child {@link FontUse} instances, i.e. the list of {@link FontUse} instances that have been
- * used by {@link #getFontConsumer}.
+ * Returns the collection of child {@link FontUse} instances, i.e. those {@link FontUse} created for this font.
* This will ordinarily contain only one instance, but in the case of Type1 fonts that require multiple encodings
* for access to all glyphs, it may contain more.
@@ -50,13 +50,12 @@
* This will ordinarily contain only one instance, but in the case of Type1 fonts that require multiple encodings
* for access to all glyphs, it may contain more.
- * @return The list of child {@link FontUse} instances.
+ * @return The collection of child {@link FontUse} instances.
*/
|